Attribute class

Constructors

Attribute(String name, dynamic initialValues)
Constructor.

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
The name of the attribute.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Set<ASN1Object>
The set of values associated with the attribute.
no setter

Methods

addStringValue(String s) → void
addValue(ASN1Object val) bool
Add a value to the existing values in the attribute.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

newAttributeMap(Map<String, dynamic> m) Map<String, Attribute>
Converts a map of simple strings or list values into a Map of Attribute.