Attribute class
Properties
Methods
-
addStringValue(
String s) → void -
addValue(
ASN1Object val) → bool - Add a value to the existing values in the attribute.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override